package com.example.demo;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Profile;
import org.springframework.stereotype.Component;
import org.springframework.validation.annotation.Validated;
import jakarta.validation.constraints.*;

// using ConfigurationProperties over Value is recommended by https://stackoverflow.com/a/35571932/147530 
// also see: https://mkyong.com/spring-boot/spring-boot-configurationproperties-example/
// and: https://github.com/callicoder/spring-boot-configuration-properties-demo
// https://docs.spring.io/spring-boot/docs/current/reference/html/features.html#features.external-config

@Component
@Service
@ConfigurationProperties
@Validated
@Profile("profile1")
public class Config1  extends BaseConfig {
    String name;

    String inputFile;

    MyEnum city;

    @Min(18) @Max(99)
    int age;

    // the getters and setters are necessary. without it spring boot does not read and bind the properties
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getInputFile() {
        return inputFile;
    }

    public void setInputFile(String inputFile) {
        this.inputFile = inputFile;
    }

    public MyEnum getCity() {
        return city;
    }

    public void setCity(MyEnum city) {
        this.city = city;
    }

    public int getAge() {
        return age;
    }

    public void setAge(int age) {
        this.age = age;
    }
}
